Module: PasskeyAuth
- Defined in:
- lib/passkey_auth.rb,
lib/passkey_auth/engine.rb,
lib/passkey_auth/version.rb,
app/models/passkey_auth/magic_link.rb,
lib/passkey_auth/concerns/passwordless.rb,
app/mailers/passkey_auth/magic_link_mailer.rb,
app/mailers/passkey_auth/application_mailer.rb,
app/models/passkey_auth/webauthn_credential.rb,
app/models/passkey_auth/magic_link/short_code.rb,
app/controllers/passkey_auth/application_controller.rb,
app/controllers/passkey_auth/magic_links_controller.rb,
lib/generators/passkey_auth/install/install_generator.rb,
app/controllers/passkey_auth/webauthn/credentials_controller.rb,
app/controllers/passkey_auth/webauthn/authentications_controller.rb,
app/controllers/passkey_auth/webauthn/credentials/challenges_controller.rb,
app/controllers/passkey_auth/webauthn/authentications/challenges_controller.rb
Defined Under Namespace
Modules: Concerns, Generators, Webauthn Classes: ApplicationController, ApplicationMailer, Engine, Error, MagicLink, MagicLinkMailer, MagicLinksController, WebauthnCredential
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
- .setup {|_self| ... } ⇒ Object
- .user_class ⇒ Object
-
.user_email(user) ⇒ Object
Helper to get the email attribute value from a user.
Class Method Details
.setup {|_self| ... } ⇒ Object
22 23 24 |
# File 'lib/passkey_auth.rb', line 22 def self.setup yield self end |
.user_class ⇒ Object
26 27 28 |
# File 'lib/passkey_auth.rb', line 26 def self.user_class user_model_name.constantize end |
.user_email(user) ⇒ Object
Helper to get the email attribute value from a user
31 32 33 |
# File 'lib/passkey_auth.rb', line 31 def self.user_email(user) user.public_send(user_email_attribute) end |